@@ -423,17 +423,36 @@ class DltkAiClient:
             raise Exception('Error while checking the status. Got ' + str(response.status_code))
 
 
-    def visual_search(self, image_path_1, image_path_2):
+    def folder_upload(self, image_folder, folder_name):
         """
         :param str image_path_1: The path of the image file
         :param str image_path_1: The path of the image file
         :return
             obj : A json obj containing matched status and value info
         """
-        body = {'image_1': (image_path_1, open(image_path_1, 'rb'), 'multipart/form-data'), 'image_2': (image_path_2, open(image_path_2, 'rb'), 'multipart/form/data')}
+        files = []
+        for i in range(len(image_folder)):
+            files.append(('files',open(image_folder[i],'rb')))
+        url = self.base_url + '/s3/folder'
+        payload = {}
+        headers = {'label': folder_name,'ApiKey': self.api_key}
+        response = requests.post(url = url, headers=headers, data = payload, files = files).json()
+        return response
+
+
+    def visual_search(self, image_path_1, image_folder):
+        """
+        :param str image_path_1: The path of the image file
+        :param str image_path_1: The path of the image file
+        :return
+            obj : A json obj containing matched status and value info
+        """
+        image_folder = str(image_folder)
+        body = {'image_1': (image_path_1, open(image_path_1, 'rb'), 'multipart/form-data')}
+        data = {'image_folder':image_folder}
         url = self.base_url + '/visual_search_ai/'
         headers = {'ApiKey': self.api_key}
-        response = requests.post(url=url, files=body, headers=headers).json()
+        response = requests.post(url=url, files=body, headers=headers, data=data).json()
         return response 
            
 
